﻿using System.Windows;
using System.Windows.Controls;
using Telerik.Windows.Controls;
using System.Windows.Media;

namespace TreeViewInComboBox
{
	public class TreeViewCombo
	{
		public static object GetSelectedItem(DependencyObject obj)
		{
			return (object)obj.GetValue(SelectedItemProperty);
		}

		public static void SetSelectedItem(DependencyObject obj, object value)
		{
			obj.SetValue(SelectedItemProperty, value);
		}

		public static readonly DependencyProperty SelectedItemProperty =
			DependencyProperty.RegisterAttached("SelectedItem", typeof(object), typeof(TreeViewCombo), null);


		public static bool GetSynchronizeWithOuterComboBox(DependencyObject obj)
		{
			return (bool)obj.GetValue(SynchronizeWithOuterComboBoxProperty);
		}

		public static void SetSynchronizeWithOuterComboBox(DependencyObject obj, bool value)
		{
			obj.SetValue(SynchronizeWithOuterComboBoxProperty, value);
		}

		public static readonly DependencyProperty SynchronizeWithOuterComboBoxProperty =
			DependencyProperty.RegisterAttached("SynchronizeWithOuterComboBox", typeof(bool), typeof(TreeViewCombo), new PropertyMetadata(OnSynchronizeWithOuterComboBoxChanged));


		private static void OnSynchronizeWithOuterComboBoxChanged(DependencyObject d, DependencyPropertyChangedEventArgs args)
		{
			(d as RadTreeView).SelectionChanged += TreeViewCombo_SelectionChanged;
		}

		private static void TreeViewCombo_SelectionChanged(object sender, Telerik.Windows.Controls.SelectionChangedEventArgs e)
		{
			RadTreeView treeView = sender as RadTreeView;
			RadComboBox comboBox = ParentOfType<RadComboBox>(treeView);

			SetSelectedItem(comboBox, treeView.SelectedItem);
			comboBox.IsDropDownOpen = false;
		}

		private static T ParentOfType<T>(FrameworkElement element) where T : DependencyObject
		{
			if (element == null) return null;

			FrameworkElement parent = (FrameworkElement)(element.Parent ?? VisualTreeHelper.GetParent(element));

			while ((parent != null) && !(parent is T))
			{
				parent = (FrameworkElement)(parent.Parent ?? VisualTreeHelper.GetParent(parent));
			}

			return parent as T;
		}
	}
}